# dirs = dirname(__file__).replace("\\", "/").split("/")[:-1]
# path.append("/".join(dirs))
# dirs.append("helpful")
# path.append("/".join(dirs))

from .stup_debugger import *